# agipy

[![Build Status](https://travis-ci.org/shimst3r/agipy.svg?branch=master)](https://travis-ci.org/shimst3r/agipy)

> /əˈdʒɪˈpaɪ/, portmanteau of AgI (chemical formula of silver iodide) and Python

`agipy` enables you to destroy cloud infrastructure in a hurry. Whether you want to destroy a demo
environment you no longer need or want to purge artifacts a colleague left behind, `agipy` is here
to help you dissolving your cloud problems.

## About the name

`agipy` is a portmanteau of the chemical formula AgI for silver iodide and the word Python. Silver
iodide is a chemical used for [cloud seeding](https://en.wikipedia.org/wiki/Cloud_seeding#Methodology)
and [Python](https://www.python.org/) is the language `agipy` is implemented in.
